summaryrefslogtreecommitdiffstats
path: root/sys/contrib/dev/acpica/exutils.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/contrib/dev/acpica/exutils.c')
-rw-r--r--sys/contrib/dev/acpica/exutils.c18
1 files changed, 8 insertions, 10 deletions
diff --git a/sys/contrib/dev/acpica/exutils.c b/sys/contrib/dev/acpica/exutils.c
index 407894d..0bf2ff2 100644
--- a/sys/contrib/dev/acpica/exutils.c
+++ b/sys/contrib/dev/acpica/exutils.c
@@ -2,7 +2,7 @@
/******************************************************************************
*
* Module Name: exutils - interpreter/scanner utilities
- * $Revision: 85 $
+ * $Revision: 88 $
*
*****************************************************************************/
@@ -152,7 +152,6 @@
* PARAMETERS: None
*
* DESCRIPTION: Enter the interpreter execution region
- * TBD: should be a macro
*
******************************************************************************/
@@ -187,8 +186,6 @@ AcpiExEnterInterpreter (void)
* already executing
* 7) About to invoke a user-installed opregion handler
*
- * TBD: should be a macro
- *
******************************************************************************/
void
@@ -281,7 +278,8 @@ AcpiExTruncateFor32bitTable (
*
* FUNCTION: AcpiExAcquireGlobalLock
*
* PARAMETERS: Rule - Lock rule: AlwaysLock, NeverLock
*
* RETURN: TRUE/FALSE indicating whether the lock was actually acquired
*
@@ -293,7 +291,7 @@ AcpiExTruncateFor32bitTable (
BOOLEAN
AcpiExAcquireGlobalLock (
- UINT32 Rule)
+ UINT32 FieldFlags)
{
BOOLEAN Locked = FALSE;
ACPI_STATUS Status;
@@ -302,9 +300,9 @@ AcpiExAcquireGlobalLock (
FUNCTION_TRACE ("ExAcquireGlobalLock");
- /* Only attempt lock if the Rule says so */
+ /* Only attempt lock if the AlwaysLock bit is set */
- if (Rule == (UINT32) GLOCK_ALWAYS_LOCK)
+ if (FieldFlags & AML_FIELD_LOCK_RULE_MASK)
{
/* We should attempt to get the lock */
@@ -392,8 +390,8 @@ AcpiExDigitsNeeded (
/*
* ACPI_INTEGER is unsigned, which is why we don't worry about a '-'
*/
- for (NumDigits = 1;
- (AcpiUtShortDivide (&Value, Base, &Value, NULL));
+ for (NumDigits = 1;
+ (AcpiUtShortDivide (&Value, Base, &Value, NULL));
++NumDigits)
{ ; }
}
OpenPOWER on IntegriCloud
@@ -281,7 +278,8 @@ AcpiExTruncateFor32bitTable (
* FUNCTION: AcpiExAcquireGlobalLock
*
- * PARAMETERS: Rule - Lock rule: AlwaysLock, NeverLock
+ * PARAMETERS: FieldFlags - Flags with Lock rule:
+ * AlwaysLock or NeverLock
*
* RETURN: TRUE/FALSE indicating whether the lock was actually acquired